@@ -1,5 +1,3 @@
-mod big_int_api;
-mod big_uint_api;
 mod blockchain_api;
 mod call_value_api;
 mod contract_abi_api;
@@ -10,13 +8,12 @@ mod endpoint_arg_api;
 mod endpoint_finish_api;
 mod error_api;
 mod log_api;
+mod managed_types;
 mod proxy_obj_api;
 mod send_api;
 mod storage_api;
 pub mod uncallable;
 
-pub use big_int_api::*;
-pub use big_uint_api::*;
 pub use blockchain_api::*;
 pub use call_value_api::*;
 pub use contract_abi_api::*;
@@ -27,6 +24,7 @@ pub use endpoint_arg_api::*;
 pub use endpoint_finish_api::*;
 pub use error_api::*;
 pub use log_api::*;
+pub use managed_types::*;
 pub use proxy_obj_api::*;
 pub use send_api::{SendApi, ESDT_NFT_TRANSFER_STRING, ESDT_TRANSFER_STRING};
 pub use storage_api::*;
