@@ -3,6 +3,7 @@ mod async_call;
 mod callback_call;
 mod callback_selector_result;
 mod contract_call;
+mod contract_deploy;
 mod send_egld;
 mod send_esdt;
 mod send_token;
@@ -12,6 +13,7 @@ pub use async_call::AsyncCall;
 pub use callback_call::CallbackCall;
 pub use callback_selector_result::CallbackSelectorResult;
 pub use contract_call::{new_contract_call, ContractCall};
+pub use contract_deploy::{new_contract_deploy, ContractDeploy};
 pub use send_egld::SendEgld;
 pub use send_esdt::SendEsdt;
 pub use send_token::SendToken;
